@@ -33,8 +33,6 @@
 #include "pango-engine.h"
 #include "pango-utils.h"
 
-#include "basic-common.h"
-
 /* No extra fields needed */
 typedef PangoEngineShape      BasicEngineWin32;
 typedef PangoEngineShapeClass BasicEngineWin32Class ;
@@ -43,30 +41,7 @@ typedef PangoEngineShapeClass BasicEngineWin32Class ;
 
 static gboolean pango_win32_debug = FALSE;
 
-#ifdef HAVE_USP10_H
-
-#include "usp10.h"
-
-/* Some languages missing from mingw ("w32api") headers */
-
-#ifndef LANG_INVARIANT
-#define LANG_INVARIANT 0x7f
-#endif
-#ifndef LANG_DIVEHI
-#define LANG_DIVEHI 0x65
-#endif
-#ifndef LANG_GALICIAN
-#define LANG_GALICIAN 0x56
-#endif
-#ifndef LANG_KYRGYZ
-#define LANG_KYRGYZ 0x40
-#endif
-#ifndef LANG_MONGOLIAN
-#define LANG_MONGOLIAN 0x50
-#endif
-#ifndef LANG_SYRIAC
-#define LANG_SYRIAC 0x5a
-#endif
+#include <usp10.h>
 
 static gboolean have_uniscribe = FALSE;
 
@@ -122,14 +97,10 @@ static const SCRIPT_PROPERTIES **scripts;
 static int nscripts;
 #endif
 
-#endif
-
-#ifdef HAVE_USP10_H
 static PangoEngineScriptInfo uniscribe_scripts[] = {
   /* We claim to cover everything ;-) */
   { PANGO_SCRIPT_COMMON,  "" },
 };
-#endif
 
 static PangoEngineScriptInfo basic_scripts[] = {
   /* Those characters that can be rendered legibly without Uniscribe.
@@ -177,7 +148,7 @@ static PangoEngineInfo script_engines[] = {
   }
 };
 
-static PangoGlyph 
+static PangoGlyph
 find_char (PangoFont *font,
 	   gunichar   wc)
 {
@@ -194,7 +165,7 @@ set_glyph (PangoFont        *font,
   PangoRectangle logical_rect;
 
   glyphs->glyphs[i].glyph = glyph;
-  
+
   glyphs->glyphs[i].geometry.x_offset = 0;
   glyphs->glyphs[i].geometry.y_offset = 0;
 
@@ -210,16 +181,16 @@ swap_range (PangoGlyphString *glyphs,
 	    int               end)
 {
   int i, j;
-  
+
   for (i = start, j = end - 1; i < j; i++, j--)
     {
       PangoGlyphInfo glyph_info;
       gint log_cluster;
-      
+
       glyph_info = glyphs->glyphs[i];
       glyphs->glyphs[i] = glyphs->glyphs[j];
       glyphs->glyphs[j] = glyph_info;
-      
+
       log_cluster = glyphs->log_clusters[i];
       glyphs->log_clusters[i] = glyphs->log_clusters[j];
       glyphs->log_clusters[j] = log_cluster;
@@ -228,205 +199,20 @@ swap_range (PangoGlyphString *glyphs,
 
 #ifdef BASIC_WIN32_DEBUGGING
 
-#if 0
-
-static char *
-charset_name (int charset)
-{
-  static char unk[10];
-
-  switch (charset)
-    {
-#define CASE(n) case n##_CHARSET: return #n
-      CASE (ANSI);
-      CASE (DEFAULT);
-      CASE (SYMBOL);
-      CASE (SHIFTJIS);
-      CASE (HANGEUL);
-      CASE (GB2312);
-      CASE (CHINESEBIG5);
-      CASE (OEM);
-      CASE (JOHAB);
-      CASE (HEBREW);
-      CASE (ARABIC);
-      CASE (GREEK);
-      CASE (TURKISH);
-      CASE (VIETNAMESE);
-      CASE (THAI);
-      CASE (EASTEUROPE);
-      CASE (RUSSIAN);
-      CASE (MAC);
-      CASE (BALTIC);
-#undef CASE
-    default:
-      sprintf (unk, "%d", charset);
-      return unk;
-    }
-}
-
-#endif
-
 static char *
 lang_name (int lang)
 {
-  static char unk[10];
-  
-  switch (PRIMARYLANGID (lang))
-    {
-#define CASE(n) case LANG_##n: return #n
-      CASE (NEUTRAL);
-#ifdef LANG_INVARIANT
-      CASE (INVARIANT);
-#endif
-      CASE (AFRIKAANS);
-      CASE (ALBANIAN);
-      CASE (ARABIC);
-#ifdef LANG_ARMENIAN
-      CASE (ARMENIAN);
-#endif
-#ifdef LANG_ASSAMESE
-      CASE (ASSAMESE);
-#endif
-#ifdef LANG_AZERI
-      CASE (AZERI);
-#endif
-      CASE (BASQUE);
-      CASE (BELARUSIAN);
-#ifdef LANG_BENGALI
-      CASE (BENGALI);
-#endif
-      CASE (BULGARIAN);
-      CASE (CATALAN);
-      CASE (CHINESE);
-      CASE (CROATIAN);
-      CASE (CZECH);
-      CASE (DANISH);
-#ifdef LANG_DIVEHI
-      CASE (DIVEHI);
-#endif
-      CASE (DUTCH);
-      CASE (ENGLISH);
-      CASE (ESTONIAN);
-      CASE (FAEROESE);
-      CASE (FARSI);
-      CASE (FINNISH);
-      CASE (FRENCH);
-#ifdef LANG_GALICIAN
-      CASE (GALICIAN);
-#endif
-#ifdef LANG_GEORGIAN
-      CASE (GEORGIAN);
-#endif
-      CASE (GERMAN);
-      CASE (GREEK);
-#ifdef LANG_GUJARATI
-      CASE (GUJARATI);
-#endif
-      CASE (HEBREW);
-#ifdef LANG_HINDI
-      CASE (HINDI);
-#endif
-      CASE (HUNGARIAN);
-      CASE (ICELANDIC);
-      CASE (INDONESIAN);
-      CASE (ITALIAN);
-      CASE (JAPANESE);
-#ifdef LANG_KANNADA
-      CASE (KANNADA);
-#endif
-#ifdef LANG_KASHMIRI
-      CASE (KASHMIRI);
-#endif
-#ifdef LANG_KAZAK
-      CASE (KAZAK);
-#endif
-#ifdef LANG_KONKANI
-      CASE (KONKANI);
-#endif
-      CASE (KOREAN);
-#ifdef LANG_KYRGYZ
-      CASE (KYRGYZ);
-#endif
-      CASE (LATVIAN);
-      CASE (LITHUANIAN);
-#ifdef LANG_MACEDONIAN
-      CASE (MACEDONIAN);
-#endif
-#ifdef LANG_MALAY
-      CASE (MALAY);
-#endif
-#ifdef LANG_MALAYALAM
-      CASE (MALAYALAM);
-#endif
-#ifdef LANG_MANIPURI
-      CASE (MANIPURI);
-#endif
-#ifdef LANG_MARATHI
-      CASE (MARATHI);
-#endif
-#ifdef LANG_MONGOLIAN
-      CASE (MONGOLIAN);
-#endif
-#ifdef LANG_NEPALI
-      CASE (NEPALI);
-#endif
-      CASE (NORWEGIAN);
-#ifdef LANG_ORIYA
-      CASE (ORIYA);
-#endif
-      CASE (POLISH);
-      CASE (PORTUGUESE);
-#ifdef LANG_PUNJABI
-      CASE (PUNJABI);
-#endif
-      CASE (ROMANIAN);
-      CASE (RUSSIAN);
-#ifdef LANG_SANSKRIT
-      CASE (SANSKRIT);
-#endif
-#ifdef LANG_SINDHI
-      CASE (SINDHI);
-#endif
-      CASE (SLOVAK);
-      CASE (SLOVENIAN);
-      CASE (SPANISH);
-#ifdef LANG_SWAHILI
-      CASE (SWAHILI);
-#endif
-      CASE (SWEDISH);
-#ifdef LANG_SYRIAC
-      CASE (SYRIAC);
-#endif
-#ifdef LANG_TAMIL
-      CASE (TAMIL);
-#endif
-#ifdef LANG_TATAR
-      CASE (TATAR);
-#endif
-#ifdef LANG_TELUGU
-      CASE (TELUGU);
-#endif
-      CASE (THAI);
-      CASE (TURKISH);
-      CASE (UKRAINIAN);
-#ifdef LANG_URDU
-      CASE (URDU);
-#endif
-#ifdef LANG_UZBEK
-      CASE (UZBEK);
-#endif
-      CASE (VIETNAMESE);
-#undef CASE
-    default:
-      sprintf (unk, "%#02x", lang);
-      return unk;
-    }
+  LCID lcid = MAKELCID (lang, SORT_DEFAULT);
+  static char retval[10];
+
+  if (!GetLocaleInfo (lcid, LOCALE_SISO639LANGNAME, retval, G_N_ELEMENTS (retval)))
+    sprintf (retval, "%#02x", lang);
+
+  return retval;
 }
 
 #endif /* BASIC_WIN32_DEBUGGING */
 
-#ifdef HAVE_USP10_H
-
 static WORD
 make_langid (PangoLanguage *lang)
 {
@@ -503,23 +289,23 @@ dump_glyphs_and_log_clusters (gboolean rtl,
   {
     int j, k, nclusters, clusterix, charix, ng;
 
-    printf ("  ScriptShape: nglyphs=%d: ", nglyphs);
+    g_print ("  ScriptShape: nglyphs=%d: ", nglyphs);
 
     for (j = 0; j < nglyphs; j++)
-      printf ("%d%s", iglyphs[j], (j < nglyphs-1) ? "," : "");
-    printf ("\n");
+      g_print ("%d%s", iglyphs[j], (j < nglyphs-1) ? "," : "");
+    g_print ("\n");
 
-    printf ("  log_clusters: ");
+    g_print ("  log_clusters: ");
     for (j = 0; j < itemlen; j++)
-      printf ("%d ", log_clusters[j]);
-    printf ("\n");
+      g_print ("%d ", log_clusters[j]);
+    g_print ("\n");
     nclusters = 0;
     for (j = 0; j < itemlen; j++)
       {
 	if (j == 0 || log_clusters[j-1] != log_clusters[j])
 	  nclusters++;
       }
-    printf ("  %d clusters:\n", nclusters);
+    g_print ("  %d clusters:\n", nclusters);
 
     /* If RTL, first char is the last in the run, otherwise the
      * first.
@@ -531,22 +317,22 @@ dump_glyphs_and_log_clusters (gboolean rtl,
 	for (j = itemlen - 1, charix = charix0 + j; j >= 0; j--, charix--)
 	  {
 	    if (j == itemlen - 1 || log_clusters[j] != log_clusters[j+1])
-	      printf ("  Cluster %d: chars %d--",
-		      clusterix, charix);
+	      g_print ("  Cluster %d: chars %d--",
+		       clusterix, charix);
 	    if (j == 0 || log_clusters[j-1] != log_clusters[j])
 	      {
 		ng = log_clusters[j] - firstglyphix + 1;
-		printf ("%d: %d glyphs: ",
-			charix, ng);
+		g_print ("%d: %d glyphs: ",
+			 charix, ng);
 		for (k = firstglyphix; k <= log_clusters[j]; k++)
 		  {
-		    printf ("%d", iglyphs[k]);
+		    g_print ("%d", iglyphs[k]);
 		    if (k < log_clusters[j])
-		      printf (",");
+		      g_print (",");
 		  }
 		firstglyphix = log_clusters[j] + 1;
 		clusterix++;
-		printf ("\n");
+		g_print ("\n");
 	      }
 	  }
       }
@@ -555,22 +341,22 @@ dump_glyphs_and_log_clusters (gboolean rtl,
 	for (j = 0, charix = charix0; j < itemlen; j++, charix++)
 	  {
 	    if (j == 0 || log_clusters[j-1] != log_clusters[j])
-	      printf ("  Cluster %d: wchar_t %d--",
-		      clusterix, charix);
+	      g_print ("  Cluster %d: wchar_t %d--",
+		       clusterix, charix);
 	    if (j == itemlen - 1 || log_clusters[j] != log_clusters[j+1])
 	      {
 		int klim = ((j == itemlen-1) ? nglyphs : log_clusters[j+1]);
 		ng = klim - log_clusters[j];
-		printf ("%d: %d glyphs: ",
-			charix, ng);
+		g_print ("%d: %d glyphs: ",
+			 charix, ng);
 		for (k = log_clusters[j]; k < klim; k++)
 		  {
-		    printf ("%d", iglyphs[k]);
+		    g_print ("%d", iglyphs[k]);
 		    if (k != klim - 1)
-		      printf (",");
+		      g_print (",");
 		  }
 		clusterix++;
-		printf ("\n");
+		g_print ("\n");
 	      }
 	  }
       }
@@ -699,18 +485,18 @@ convert_log_clusters_to_byte_offsets (const char       *text,
       g_assert (glyphs->log_clusters[glyphix] < n_chars);
       glyphs->log_clusters[glyphix] = byte_offset[glyphs->log_clusters[glyphix]];
     }
-  
+
   g_free (byte_offset);
 }
 
 static gboolean
-itemize_shape_and_place (PangoFont        *font,
-			 HDC               hdc,
-			 wchar_t          *wtext,
-			 int               wlen,
-			 PangoAnalysis    *analysis,
-			 PangoGlyphString *glyphs,
-			 SCRIPT_CACHE     *script_cache)
+itemize_shape_and_place (PangoFont           *font,
+			 HDC                  hdc,
+			 wchar_t             *wtext,
+			 int                  wlen,
+			 const PangoAnalysis *analysis,
+			 PangoGlyphString    *glyphs,
+			 SCRIPT_CACHE        *script_cache)
 {
   int i;
   int item, nitems, item_step;
@@ -725,25 +511,25 @@ itemize_shape_and_place (PangoFont        *font,
 
   control.uDefaultLanguage = make_langid (analysis->language);
   state.uBidiLevel = analysis->level;
-  
+
 #ifdef BASIC_WIN32_DEBUGGING
   if (pango_win32_debug)
-    printf (G_STRLOC ": ScriptItemize: uDefaultLanguage:%04x uBidiLevel:%d\n",
-	    control.uDefaultLanguage, state.uBidiLevel);
+    g_print (G_STRLOC ": ScriptItemize: uDefaultLanguage:%04x uBidiLevel:%d\n",
+	     control.uDefaultLanguage, state.uBidiLevel);
 #endif
   if ((*script_itemize) (wtext, wlen, G_N_ELEMENTS (items), &control, NULL,
 			 items, &nitems))
     {
 #ifdef BASIC_WIN32_DEBUGGING
       if (pango_win32_debug)
-	printf ("ScriptItemize failed\n");
+	g_print ("ScriptItemize failed\n");
 #endif
       return FALSE;
     }
 
 #ifdef BASIC_WIN32_DEBUGGING
   if (pango_win32_debug)
-    printf ("%d items:\n", nitems);
+    g_print ("%d items:\n", nitems);
 #endif
 
   if (analysis->level % 2)
@@ -772,7 +558,7 @@ itemize_shape_and_place (PangoFont        *font,
       memset (advances, 0, sizeof (advances));
       memset (offsets, 0, sizeof (offsets));
       memset (&abc, 0, sizeof (abc));
-	  
+
       /* Note that itemlen is number of wchar_t's i.e. surrogate pairs
        * count as two!
        */
@@ -781,17 +567,17 @@ itemize_shape_and_place (PangoFont        *font,
 
 #ifdef BASIC_WIN32_DEBUGGING
       if (pango_win32_debug)
-	printf ("  Item %d: iCharPos=%d eScript=%d (%s) %s%s%s%s%s%s%s wchar_t %d--%d (%d)\n",
-		item, items[item].iCharPos, script,
-		lang_name (scripts[script]->langid),
-		scripts[script]->fComplex ? "complex" : "simple",
-		items[item].a.fRTL ? " fRTL" : "",
-		items[item].a.fLayoutRTL ? " fLayoutRTL" : "",
-		items[item].a.fLinkBefore ? " fLinkBefore" : "",
-		items[item].a.fLinkAfter ? " fLinkAfter" : "",
-		items[item].a.fLogicalOrder ? " fLogicalOrder" : "",
-		items[item].a.fNoGlyphIndex ? " fNoGlyphIndex" : "",
-		items[item].iCharPos, items[item+1].iCharPos-1, itemlen);
+	g_print ("  Item %d: iCharPos=%d eScript=%d (%s) %s%s%s%s%s%s%s wchar_t %d--%d (%d)\n",
+		 item, items[item].iCharPos, script,
+		 lang_name (scripts[script]->langid),
+		 scripts[script]->fComplex ? "complex" : "simple",
+		 items[item].a.fRTL ? " fRTL" : "",
+		 items[item].a.fLayoutRTL ? " fLayoutRTL" : "",
+		 items[item].a.fLinkBefore ? " fLinkBefore" : "",
+		 items[item].a.fLinkAfter ? " fLinkAfter" : "",
+		 items[item].a.fLogicalOrder ? " fLogicalOrder" : "",
+		 items[item].a.fNoGlyphIndex ? " fNoGlyphIndex" : "",
+		 items[item].iCharPos, items[item+1].iCharPos-1, itemlen);
 #endif
 
       items[item].a.fRTL = analysis->level % 2;
@@ -806,11 +592,11 @@ itemize_shape_and_place (PangoFont        *font,
 	{
 #ifdef BASIC_WIN32_DEBUGGING
 	  if (pango_win32_debug)
-	    printf ("pango-basic-win32: ScriptShape failed\n");
+	    g_print ("pango-basic-win32: ScriptShape failed\n");
 #endif
 	  return FALSE;
 	}
-      
+
 #ifdef BASIC_WIN32_DEBUGGING
       dump_glyphs_and_log_clusters (items[item].a.fRTL, itemlen,
 				    items[item].iCharPos, log_clusters,
@@ -819,7 +605,7 @@ itemize_shape_and_place (PangoFont        *font,
 
       ng = glyphs->num_glyphs;
       pango_glyph_string_set_size (glyphs, ng + nglyphs);
-      
+
       set_up_pango_log_clusters (wtext,
 				 items[item].a.fRTL, itemlen, log_clusters,
 				 nglyphs, glyphs->log_clusters + ng,
@@ -831,7 +617,7 @@ itemize_shape_and_place (PangoFont        *font,
 	{
 #ifdef BASIC_WIN32_DEBUGGING
 	  if (pango_win32_debug)
-	    printf ("pango-basic-win32: ScriptPlace failed\n");
+	    g_print ("pango-basic-win32: ScriptPlace failed\n");
 #endif
 	  return FALSE;
 	}
@@ -866,10 +652,10 @@ itemize_shape_and_place (PangoFont        *font,
 #ifdef BASIC_WIN32_DEBUGGING
   if (pango_win32_debug)
     {
-      printf ("  Pango log_clusters (level:%d), char index:", analysis->level);
+      g_print ("  Pango log_clusters (level:%d), char index:", analysis->level);
       for (glyphix = 0; glyphix < glyphs->num_glyphs; glyphix++)
-	printf ("%d ", glyphs->log_clusters[glyphix]);
-      printf ("\n");
+	g_print ("%d ", glyphs->log_clusters[glyphix]);
+      g_print ("\n");
     }
 #endif
 
@@ -877,11 +663,11 @@ itemize_shape_and_place (PangoFont        *font,
 }
 
 static gboolean
-uniscribe_shape (PangoFont        *font,
-		 const char       *text,
-		 gint              length,
-		 PangoAnalysis    *analysis,
-		 PangoGlyphString *glyphs)
+uniscribe_shape (PangoFont           *font,
+		 const char          *text,
+		 gint                 length,
+		 const PangoAnalysis *analysis,
+		 PangoGlyphString    *glyphs)
 {
   wchar_t *wtext;
   long wlen;
@@ -904,7 +690,7 @@ uniscribe_shape (PangoFont        *font,
 	if (script_cache[i])
 	  (*script_free_cache)(&script_cache[i]);
     }
-  
+
   if (retval)
     {
       convert_log_clusters_to_byte_offsets (text, length, glyphs);
@@ -913,10 +699,10 @@ uniscribe_shape (PangoFont        *font,
 	{
 	  int glyphix;
 
-	  printf ("  Pango log_clusters, byte offsets:");
+	  g_print ("  Pango log_clusters, byte offsets:");
 	  for (glyphix = 0; glyphix < glyphs->num_glyphs; glyphix++)
-	    printf ("%d ", glyphs->log_clusters[glyphix]);
-	  printf ("\n");
+	    g_print ("%d ", glyphs->log_clusters[glyphix]);
+	  g_print ("\n");
 	}
 #endif
     }
@@ -946,22 +732,20 @@ text_is_simple (const char *text,
 
 #ifdef BASIC_WIN32_DEBUGGING
   if (pango_win32_debug)
-    printf ("text_is_simple: %.*s (%ld wchar_t): %s\n",
-	    MIN (length, 10), text, wlen, retval ? "YES" : "NO");
+    g_print ("text_is_simple: %.*s (%ld wchar_t): %s\n",
+	     MIN (length, 10), text, wlen, retval ? "YES" : "NO");
 #endif
 
   return retval;
 }
-		
-#endif /* HAVE_USP10_H */
 
-static void 
-basic_engine_shape (PangoEngineShape *engine,
-		    PangoFont        *font,
-		    const char       *text,
-		    gint              length,
-		    PangoAnalysis    *analysis,
-		    PangoGlyphString *glyphs)
+static void
+basic_engine_shape (PangoEngineShape 	*engine,
+		    PangoFont        	*font,
+		    const char       	*text,
+		    int              	 length,
+		    const PangoAnalysis *analysis,
+		    PangoGlyphString    *glyphs)
 {
   int n_chars;
   int i;
@@ -972,15 +756,11 @@ basic_engine_shape (PangoEngineShape *engine,
   g_return_if_fail (length >= 0);
   g_return_if_fail (analysis != NULL);
 
-#ifdef HAVE_USP10_H
-
   if (have_uniscribe &&
       !text_is_simple (text, length) &&
       uniscribe_shape (font, text, length, analysis, glyphs))
     return;
 
-#endif
-
   n_chars = g_utf8_strlen (text, length);
 
   pango_glyph_string_set_size (glyphs, n_chars);
@@ -1000,7 +780,7 @@ basic_engine_shape (PangoEngineShape *engine,
 
       if (wc == 0xa0)	/* non-break-space */
 	wc = 0x20;
-		
+
       if (pango_is_zero_width (wc))
 	{
 	  set_glyph (font, glyphs, i, p - text, PANGO_GLYPH_EMPTY);
@@ -1011,13 +791,13 @@ basic_engine_shape (PangoEngineShape *engine,
 	  if (index)
 	    {
 	      set_glyph (font, glyphs, i, p - text, index);
-	      
+
 	      if (g_unichar_type (wc) == G_UNICODE_NON_SPACING_MARK)
 		{
 		  if (i > 0)
 		    {
 		      PangoRectangle logical_rect, ink_rect;
-		      
+
 		      glyphs->glyphs[i].geometry.width = MAX (glyphs->glyphs[i-1].geometry.width,
 							      glyphs->glyphs[i].geometry.width);
 		      glyphs->glyphs[i-1].geometry.width = 0;
@@ -1036,7 +816,7 @@ basic_engine_shape (PangoEngineShape *engine,
 	  else
 	    set_glyph (font, glyphs, i, p - text, PANGO_GET_UNKNOWN_GLYPH (wc));
 	}
-      
+
       p = g_utf8_next_char (p);
     }
 
@@ -1048,7 +828,7 @@ basic_engine_shape (PangoEngineShape *engine,
 
       /* Swap all glyphs */
       swap_range (glyphs, 0, n_chars);
-      
+
       /* Now reorder glyphs within each cluster back to LTR */
       for (start = 0; start < n_chars;)
 	{
@@ -1056,7 +836,7 @@ basic_engine_shape (PangoEngineShape *engine,
 	  while (end < n_chars &&
 		 glyphs->log_clusters[end] == glyphs->log_clusters[start])
 	    end++;
-	  
+
 	  swap_range (glyphs, start, end);
 	  start = end;
 	}
@@ -1066,11 +846,10 @@ basic_engine_shape (PangoEngineShape *engine,
 static void
 init_uniscribe (void)
 {
-#ifdef HAVE_USP10_H
   HMODULE usp10_dll;
 
   have_uniscribe = FALSE;
-  
+
   if ((usp10_dll = LoadLibrary ("usp10.dll")) != NULL)
     {
       (script_get_properties = (pScriptGetProperties)
@@ -1094,8 +873,7 @@ init_uniscribe (void)
 #endif
       hdc = pango_win32_get_dc ();
     }
-#endif
-} 
+}
 
 static void
 basic_engine_win32_class_init (PangoEngineShapeClass *class)
@@ -1106,7 +884,7 @@ basic_engine_win32_class_init (PangoEngineShapeClass *class)
 PANGO_ENGINE_SHAPE_DEFINE_TYPE (BasicEngineWin32, basic_engine_win32,
 				basic_engine_win32_class_init, NULL);
 
-void 
+void
 PANGO_MODULE_ENTRY(init) (GTypeModule *module)
 {
   init_uniscribe ();
@@ -1117,12 +895,12 @@ PANGO_MODULE_ENTRY(init) (GTypeModule *module)
   basic_engine_win32_register_type (module);
 }
 
-void 
+void
 PANGO_MODULE_ENTRY(exit) (void)
 {
 }
 
-void 
+void
 PANGO_MODULE_ENTRY(list) (PangoEngineInfo **engines,
 			  int              *n_engines)
 {
@@ -1131,7 +909,6 @@ PANGO_MODULE_ENTRY(list) (PangoEngineInfo **engines,
   script_engines[0].scripts = basic_scripts;
   script_engines[0].n_scripts = G_N_ELEMENTS (basic_scripts);
 
-#ifdef HAVE_USP10_H
   if (have_uniscribe)
     {
 #if 0
@@ -1154,7 +931,6 @@ PANGO_MODULE_ENTRY(list) (PangoEngineInfo **engines,
       script_engines[0].n_scripts = G_N_ELEMENTS (uniscribe_scripts);
 #endif
     }
-#endif
 
   *engines = script_engines;
   *n_engines = G_N_ELEMENTS (script_engines);
