@@ -53,7 +53,7 @@ pango_font_description_get_type (void)
 {
   static GType our_type = 0;
 
-  if (our_type == 0)
+  if (G_UNLIKELY (our_type == 0))
     our_type = g_boxed_type_register_static (I_("PangoFontDescription"),
 					     (GBoxedCopyFunc)pango_font_description_copy,
 					     (GBoxedFreeFunc)pango_font_description_free);
@@ -387,7 +387,8 @@ pango_font_description_get_size (const PangoFontDescription *desc)
  *   value of 10 * PANGO_SCALE gives a 10 pixel font.
  *
  * Sets the size field of a font description, in device units. This is mutually
- * exclusive with pango_font_description_set_size().
+ * exclusive with pango_font_description_set_size() which sets the font size
+ * in points.
  *
  * Since: 1.8
  **/
@@ -407,7 +408,7 @@ pango_font_description_set_absolute_size (PangoFontDescription *desc,
  * pango_font_description_get_size_is_absolute:
  * @desc: a #PangoFontDescription
  *
- * Determines whether the size of the font is in points or device units.
+ * Determines whether the size of the font is in points (not absolute) or device units (absolute).
  * See pango_font_description_set_size() and pango_font_description_set_absolute_size().
  *
  * Return value: whether the size for the font description is in
@@ -535,7 +536,12 @@ pango_font_description_merge (PangoFontDescription       *desc,
 			      const PangoFontDescription *desc_to_merge,
 			      gboolean                    replace_existing)
 {
-  gboolean family_merged = desc_to_merge->family_name && (replace_existing || !desc->family_name);
+  gboolean family_merged;
+
+  g_return_if_fail (desc != NULL);
+  g_return_if_fail (desc_to_merge != NULL);
+
+  family_merged = desc_to_merge->family_name && (replace_existing || !desc->family_name);
 
   pango_font_description_merge_static (desc, desc_to_merge, replace_existing);
 
@@ -567,6 +573,7 @@ pango_font_description_merge_static (PangoFontDescription       *desc,
   PangoFontMask new_mask;
 
   g_return_if_fail (desc != NULL);
+  g_return_if_fail (desc_to_merge != NULL);
 
   if (replace_existing)
     new_mask = desc_to_merge->mask;
@@ -660,7 +667,11 @@ pango_font_description_better_match (const PangoFontDescription *desc,
 PangoFontDescription *
 pango_font_description_copy  (const PangoFontDescription  *desc)
 {
-  PangoFontDescription *result = g_slice_new (PangoFontDescription);
+  PangoFontDescription *result;
+
+  g_return_val_if_fail (desc != NULL, NULL);
+
+  result = g_slice_new (PangoFontDescription);
 
   *result = *desc;
 
@@ -688,7 +699,11 @@ pango_font_description_copy  (const PangoFontDescription  *desc)
 PangoFontDescription *
 pango_font_description_copy_static (const PangoFontDescription *desc)
 {
-  PangoFontDescription *result = g_slice_new (PangoFontDescription);
+  PangoFontDescription *result;
+
+  g_return_val_if_fail (desc != NULL, NULL);
+
+  result = g_slice_new (PangoFontDescription);
 
   *result = *desc;
   if (result->family_name)
@@ -762,6 +777,8 @@ pango_font_description_hash (const PangoFontDescription *desc)
 {
   guint hash = 0;
 
+  g_return_val_if_fail (desc != NULL, 0);
+
   if (desc->family_name)
     hash = case_insensitive_hash (desc->family_name);
   hash ^= desc->size;
@@ -777,7 +794,7 @@ pango_font_description_hash (const PangoFontDescription *desc)
 
 /**
  * pango_font_description_free:
- * @desc: a #PangoFontDescription
+ * @desc: a #PangoFontDescription, or %NULL
  *
  * Frees a font description.
  **/
@@ -795,7 +812,7 @@ pango_font_description_free  (PangoFontDescription  *desc)
 
 /**
  * pango_font_descriptions_free:
- * @descs: a pointer to an array of #PangoFontDescription
+ * @descs: a pointer to an array of #PangoFontDescription, or %NULL
  * @n_descs: number of font descriptions in @descs
  *
  * Frees a list of font descriptions from pango_font_map_list_fonts()
@@ -1085,7 +1102,11 @@ append_field (GString *str, const FieldMap *map, int n_elements, int val)
 char *
 pango_font_description_to_string (const PangoFontDescription  *desc)
 {
-  GString *result = g_string_new (NULL);
+  GString *result;
+
+  g_return_val_if_fail (desc != NULL, NULL);
+
+  result = g_string_new (NULL);
 
   if (desc->family_name && desc->mask & PANGO_FONT_MASK_FAMILY)
     {
@@ -1151,9 +1172,16 @@ pango_font_description_to_string (const PangoFontDescription  *desc)
 char *
 pango_font_description_to_filename (const PangoFontDescription  *desc)
 {
-  char *result = pango_font_description_to_string (desc);
+  char *result;
   char *p;
 
+  g_return_val_if_fail (desc != NULL, NULL);
+
+  result = pango_font_description_to_string (desc);
+
+  /* XXX This should be rewritten to read char-by-char instead
+   * of byte-by-byte, to be Unicode safe.
+   */
   p = result;
   while (*p)
     {
@@ -1397,7 +1425,7 @@ pango_font_metrics_get_type (void)
 {
   static GType our_type = 0;
 
-  if (our_type == 0)
+  if (G_UNLIKELY (our_type == 0))
     our_type = g_boxed_type_register_static (I_("PangoFontMetrics"),
 					     (GBoxedCopyFunc)pango_font_metrics_ref,
 					     (GBoxedFreeFunc)pango_font_metrics_unref);
@@ -1748,6 +1776,29 @@ pango_font_face_describe (PangoFontFace *face)
   return PANGO_FONT_FACE_GET_CLASS (face)->describe (face);
 }
 
+/**
+ * pango_font_face_is_synthesized:
+ * @face: a #PangoFontFace
+ *
+ * Returns whether a #PangoFontFace is synthesized by the underlying
+ * font rendering engine from another face, perhaps by shearing, emboldening,
+ * or lightening it.
+ *
+ * Return value: whether @face is synthesized.
+ *
+ * Since: 1.18
+ **/
+gboolean
+pango_font_face_is_synthesized (PangoFontFace  *face)
+{
+  g_return_val_if_fail (PANGO_IS_FONT_FACE (face), FALSE);
+
+  if (PANGO_FONT_FACE_GET_CLASS (face)->is_synthesized != NULL)
+    return PANGO_FONT_FACE_GET_CLASS (face)->is_synthesized (face);
+  else
+    return FALSE;
+}
+
 /**
  * pango_font_face_get_face_name:
  * @face: a #PangoFontFace.
